MixtureAnchorSelection
======================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: MixtureAnchorSelection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MixtureAnchorSelection.__call__
      ~MixtureAnchorSelection.iter_extra_repr

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: iter_extra_repr
